/*
 * kroots.cpp
 *
 * Copyright (C) 2008 Jonathan Fine (were.Vire@gmail.com)
 *
 * This file is part of KRoots.
 *
 * KRoots is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * KRoots is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with KRoots.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "kroots.h"
#include "krootsview.h"
#include "settings.h"

#include <kconfigdialog.h>

#include <kaction.h>
#include <kactioncollection.h>
#include <kstandardaction.h>

#include <KDE/KLocale>

KRoots::KRoots()
    : KXmlGuiWindow(),
      m_view(new KRootsView(this))
{
    // tell the KXmlGuiWindow that this is indeed the main widget
    setCentralWidget(m_view);

    // then, setup our actions
    setupActions();

    setupGUI();
}

KRoots::~KRoots()
{
}

void KRoots::setupActions()
{
    KStandardAction::quit(qApp, SLOT(closeAllWindows()), actionCollection());
    KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());

    KAction *a = actionCollection()->addAction("clear");
    a->setText(i18n("Clear Graph"));
    connect( a,SIGNAL(triggered( bool)), m_view, SLOT(clearPolygons()));
    a->setEnabled( true );
    
    a = actionCollection()->addAction("draw");
    a->setText(i18n("Draw the Roots"));
    connect( a,SIGNAL(triggered( bool)), m_view, SLOT(drawPolygon()));
    a->setEnabled( true );
}

void KRoots::optionsPreferences()
{
    if ( KConfigDialog::showDialog( "settings" ) )  {
        return;
    }
    KConfigDialog *dialog = new KConfigDialog(this, "settings", Settings::self());
    QWidget *generalSettingsDlg = new QWidget;
    ui_prefs_base.setupUi(generalSettingsDlg);
    dialog->addPage(generalSettingsDlg, i18n("General"), "package_setting");
    connect(dialog, SIGNAL(settingsChanged(QString)), m_view, SLOT(settingsChanged()));
    dialog->setAttribute( Qt::WA_DeleteOnClose );
    dialog->show();
}

#include "kroots.moc"
