/*
 * krootsview.cpp
 *
 * Copyright (C) 2008 Jonathan Fine (were.Vire@gmail.com)
 *
 * This file is part of KRoots.
 *
 * KRoots is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * KRoots is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with KRoots.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "krootsview.h"
#include "settings.h"

#include <klocale.h>
#include <QtGui/QLabel>
#include <kplotobject.h>
#include <kplotpoint.h> 
#include <kplotaxis.h>
#include <QtCore/QtDebug>

#include <cmath>

KRootsView::KRootsView(QWidget *)
	   : QWidget(0), mView(new Ui::Form)
{
    mView->setupUi(this);
    settingsChanged();
    setAutoFillBackground(true);

    connect(mView->cmdDraw,SIGNAL(clicked()),SLOT(drawPolygon()));
    connect(mView->cmdClear,SIGNAL(clicked()),SLOT(clearPolygons()));
    connect(mView->complexNumber,SIGNAL(currentChanged(int)),SLOT(complexFormatChanged()));
}

KRootsView::~KRootsView()
{
}

void KRootsView::settingsChanged()
{
    mView->graph->setBackgroundColor( Settings::col_background());
    mView->graph->setForegroundColor( Settings::col_foreground());
    mView->graph->setShowGrid( Settings::bool_hasgrid());
    mView->graph->setGridColor( Settings::col_grid());
    if ( Settings::bool_showlabels())
    {
	mView->graph->axis(KPlotWidget::BottomAxis)->setLabel("Real");
	mView->graph->axis(KPlotWidget::LeftAxis)->setLabel("Imaginary");
    } else {
	mView->graph->axis(KPlotWidget::BottomAxis)->setLabel("");
	mView->graph->axis(KPlotWidget::LeftAxis)->setLabel("");
    }
}

void KRootsView::drawPolygon()
{
    emit mView->complexNumber->setCurrentIndex(0); //lets make sure we have r cis o calculated
    double radius = std::pow(mView->radius->value(),1.0f/(double)mView->root->value());

    mView->tblData->clear();
    mView->tblData->setRowCount(mView->root->value());
    mView->tblData->setColumnCount(3);
    mView->tblData->setHorizontalHeaderItem(0,new QTableWidgetItem(i18n("Theta")));
    mView->tblData->setHorizontalHeaderItem(1,new QTableWidgetItem(i18n("Real")));
    mView->tblData->setHorizontalHeaderItem(2,new QTableWidgetItem(i18n("Imaginary")));

    KPlotObject* polygon = new KPlotObject(mView->cmdColor->color(), KPlotObject::Lines);
    double PI = acos(-1.000f);
    double maxValue = 0;
    for (int i = 0; i < mView->root->value(); i++)
    {
        double theta = ((2 * PI * i) + mView->theta->value())/mView->root->value();
        double real = std::cos(theta)*radius;
        double imaginary = std::sin(theta)*radius;
        polygon->addPoint(QPointF(real,imaginary));
        mView->tblData->setItem(i,0, new QTableWidgetItem(i18n("%1",theta)));
        mView->tblData->setItem(i,1, new QTableWidgetItem(i18n("%1",real)));
        mView->tblData->setItem(i,2, new QTableWidgetItem(i18n("%1",imaginary)));
	maxValue = std::max(std::max(std::abs(real),std::abs(imaginary)),maxValue);
    }
    polygon->addPoint(QPointF(polygon->points()[0]->x(),polygon->points()[0]->y()));
    mView->graph->setLimits(-maxValue,maxValue,-maxValue,maxValue);
    mView->graph->addPlotObject(polygon);
}

void KRootsView::clearPolygons()
{
    mView->graph->removeAllPlotObjects();
    mView->tblData->clear();
}

void KRootsView::complexFormatChanged()
{
    switch (mView->complexNumber->currentIndex())
    {
        case 0:
            mView->radius->setValue(std::sqrt((std::pow(mView->real->value(),2) + std::pow(mView->imaginary->value(),2))));
            mView->theta->setValue(std::atan2(mView->imaginary->value(),mView->real->value()));
        break;
        case 1:
            mView->real->setValue(std::cos(mView->theta->value())*mView->radius->value());
            mView->imaginary->setValue(std::sin(mView->theta->value())*mView->radius->value());
	break;
        default:
        break;
    }

}

#include "krootsview.moc"
